@@ -23,7 +23,7 @@ class SchemaBuilder:
         """
         self._session_manager = session_manager
 
-    def add_model(self, model, exclude_fields=(), pagination_length=0, pagination_style='infinite', external_filters=[], internal_filters=[], filters_opeator=Q.AND, access_group=None, access_by_operation={}, validators_by_operation={}, internal_field_resolvers={}, exclude_fields_by_operation={}, save_as_password=[]):
+    def add_model(self, model, exclude_fields=(), pagination_length=0, pagination_style='infinite', external_filters=[], internal_filters=[], filters_opeator=Q.AND, access_group=None, access_by_operation={}, validators_by_operation={}, internal_field_resolvers={}, exclude_fields_by_operation={}, save_as_password=[], callbacks_by_operation={}, **kwargs):
         """Add model for build operations.
 
         Args:
@@ -39,6 +39,7 @@ class SchemaBuilder:
             validators_by_operation (dict): Dictionary with the validators to use for the access. {'operation': callable(info, model_instance, **kwargs), ...}
             internal_field_resolvers (dict): Dictionary with the internal field value resolvers on create_field and update_field operations
             save_as_password (list): List of fields to save as password.
+            callbacks_by_operation (dict): Dictionary with the callbacks list to use for the access. {'operation': [callable(info, model_instance, **kwargs)], ...}
         """
         #get the model name
         model_name = model.__name__
@@ -67,6 +68,7 @@ class SchemaBuilder:
             'internal_field_resolvers': internal_field_resolvers,
             'exclude_fields_by_operation': exclude_fields_by_operation,
             'save_as_password': save_as_password,
+            'callbacks_by_operation': callbacks_by_operation
         }
         self._models_config[model_name]=config
 
@@ -142,7 +144,7 @@ class SchemaBuilder:
                 #get the model name
                 model_name = self._session_manager.user_model.__name__
                 #crreate the model type
-                model_metaclass = type(f"Meta", (), {'model': self._session_manager.user_model, 'excld_fields': (self._session_manager.password_field_name,)})
+                model_metaclass = type(f"Meta", (), {'model': self._session_manager.user_model, 'exclude_fields': (self._session_manager.password_field_name,)})
                 model_type = type(f"{model_name}Type", (DjangoObjectType,), {'Meta': model_metaclass})
                 config_login_model = {
                     'model': self._session_manager.user_model,
