@@ -147,6 +147,11 @@ def build_mutate_for_create(self):
                     valid_operation=evaluate_result(config['validators_by_operation']['create_field'], info, instance, **kwargs)
                 if valid_operation:
                     instance.save()
+                    callbacks=config.get('callbacks_by_operation').get('create_field')
+                    if callbacks is not None:
+                        for callback in callbacks:
+                            if callable(callback):
+                                callback(info, instance, **kwargs)
                     return return_object(**{'estado':True, model.__name__.lower():instance, 'error':ErrorManager.get_error_by_code(NO_ERROR)})
                 else:
                     return return_object(**{'estado':False, 'error':ErrorManager.get_error_by_code(INSUFFICIENT_PERMISSIONS)})
@@ -186,33 +191,39 @@ def build_mutate_for_update(self):
                                 field_type=instance._meta.get_field(key).__class__.__name__
                                 if callable(value):
                                     value=value(info, instance, **kwargs)
-                                if field_type=='ForeignKey':
-                                    foreign_model=instance._meta.get_field(key).related_model
-                                    value=foreign_model.objects.get(id=value)
-                                    setattr(instance, key, value)
-                                elif field_type=='FileField':
-                                    file=File(value)
-                                    extension=file.name.split('.')[-1]
-                                    sha1_file=HashManager.getSHA1file(file)
-                                    getattr(instance, key).save(f'{sha1_file}.{extension}', file, save=False)
-                                elif field_type=='ImageField':
-                                    #test if is a valid image
-                                    Image.open(value)
-                                    file=ImageFile(value)
-                                    extension=file.name.split('.')[-1]
-                                    sha1_file=HashManager.getSHA1file(file)
-                                    getattr(instance, key).save(f'{sha1_file}.{extension}', file, save=False)
-                                elif key in config.get('save_as_password'):
-                                    value=make_password(value)
-                                    setattr(instance, key, value)
-                                else:
-                                    if getattr(model, key).field.choices!=None and len(getattr(model, key).field.choices)>0:
-                                        choices=getattr(model, key).field.choices
-                                        valid_options=[c[0] for c in choices]
-                                        if value not in valid_options:
-                                            raise Exception(f'{value} no es una opción válida para {key}')
-                                    setattr(instance, key, value)
+                                if value!=None:
+                                    if field_type=='ForeignKey':
+                                        foreign_model=instance._meta.get_field(key).related_model
+                                        value=foreign_model.objects.get(id=value)
+                                        setattr(instance, key, value)
+                                    elif field_type=='FileField':
+                                        file=File(value)
+                                        extension=file.name.split('.')[-1]
+                                        sha1_file=HashManager.getSHA1file(file)
+                                        getattr(instance, key).save(f'{sha1_file}.{extension}', file, save=False)
+                                    elif field_type=='ImageField':
+                                        #test if is a valid image
+                                        Image.open(value)
+                                        file=ImageFile(value)
+                                        extension=file.name.split('.')[-1]
+                                        sha1_file=HashManager.getSHA1file(file)
+                                        getattr(instance, key).save(f'{sha1_file}.{extension}', file, save=False)
+                                    elif key in config.get('save_as_password'):
+                                        value=make_password(value)
+                                        setattr(instance, key, value)
+                                    else:
+                                        if getattr(model, key).field.choices!=None and len(getattr(model, key).field.choices)>0:
+                                            choices=getattr(model, key).field.choices
+                                            valid_options=[c[0] for c in choices]
+                                            if value not in valid_options:
+                                                raise Exception(f'{value} no es una opción válida para {key}')
+                                        setattr(instance, key, value)
                         instance.save()
+                        callbacks=config.get('callbacks_by_operation').get('update_field')
+                        if callbacks is not None:
+                            for callback in callbacks:
+                                if callable(callback):
+                                    callback(info, instance, **kwargs)
                         return return_object(**{'estado':True, model.__name__.lower():instance, 'error':ErrorManager.get_error_by_code(NO_ERROR)})
                     else:
                         return return_object(**{'estado':False, 'error':ErrorManager.get_error_by_code(INSUFFICIENT_PERMISSIONS)})
@@ -244,6 +255,11 @@ def build_mutate_for_delete(self):
                     if 'delete_field' in config['validators_by_operation']:
                         valid_operation=evaluate_result(config['validators_by_operation']['delete_field'], info, instance, **kwargs)
                     if valid_operation:
+                        callbacks=config.get('callbacks_by_operation').get('delete_field')
+                        if callbacks is not None:
+                            for callback in callbacks:
+                                if callable(callback):
+                                    callback(info, instance, **kwargs)
                         instance.delete()
                         return return_object(**{'estado':True, 'error':ErrorManager.get_error_by_code(NO_ERROR)})
                     else:
