@@ -93,11 +93,12 @@ class Manager:
     social_origin_facebook='FACEBOOK'
     social_origin_google='GOOGLE'
 
-    def __init__(self, user_model, use_social_session=False, rol_field_name='rol', login_id_field_name='uname', password_field_name='password', name_field_name="name", photo_field_name="photo", social_id_field=None, social_origin_field=None, active_field_name=None, session_expiration_time=12, groups={}, modify_permissions={}, security_key=None):
+    def __init__(self, user_model, session_key=None, use_social_session=False, rol_field_name='rol', login_id_field_name='uname', password_field_name='password', name_field_name="name", photo_field_name="photo", social_id_field=None, social_origin_field=None, active_field_name=None, session_expiration_time=12, groups={}, modify_permissions={}, security_key=None):
         """Session Manager for a user_model
 
         Args:
             user_model (django.models.Model): User model
+            session_key (str, optional): Session key to identify the session. Defaults to None for only one schema.
             use_social_session (bool, optional): Use social session. Defaults to False.
             rol_field_name (str, optional): Field name of user model for access level control. Defaults to 'rol'.
             login_id_field_name (str, optional): Field name of unique field used for authentication. Defaults to 'uname'.
@@ -116,6 +117,7 @@ class Manager:
         if id_attribute.field.unique==False:
             raise Exception('Field '+login_id_field_name+' must be unique')
         self.user_model=user_model
+        self.session_key=session_key
         self.use_social_session=use_social_session
         self.rol_field_name=rol_field_name
         self.login_id_field_name=login_id_field_name
@@ -146,6 +148,8 @@ class Manager:
                     'session_id':session_id,
                     'u_id': user_instance.id,
                 }
+                if self.session_key!=None:
+                    payload['session_key']=self.session_key
                 if expiration_time>0:
                     payload['exp']=tz.localtime()+datetime.timedelta(hours=expiration_time)
                 return jwt.encode(payload, self._security_key, algorithm='HS256')
@@ -167,14 +171,17 @@ class Manager:
             token=token[7:len(token)]
             try:
                 payload=jwt.decode(token, self._security_key, algorithms=['HS256'])
-                if self.user_model.objects.filter(id=payload['u_id']).exists():
-                    user_instance=self.user_model.objects.get(id=payload['u_id'])
-                    if self.group_manager.validar_acesso(user_instance, group_name):
-                        return True, user_instance, ErrorManager.get_error_by_code(NO_ERROR)
+                if self.session_key==None or self.session_key==payload['session_key']:
+                    if self.user_model.objects.filter(id=payload['u_id']).exists():
+                        user_instance=self.user_model.objects.get(id=payload['u_id'])
+                        if self.group_manager.validar_acesso(user_instance, group_name):
+                            return True, user_instance, ErrorManager.get_error_by_code(NO_ERROR)
+                        else:
+                            return False, None, ErrorManager.get_error_by_code(ACCESS_DENIED)
                     else:
-                        return False, None, ErrorManager.get_error_by_code(ACCESS_DENIED)
+                        return False, None, ErrorManager.get_error_by_code(INVALID_CREDENTIALS)
                 else:
-                    return False, None, ErrorManager.get_error_by_code(INVALID_CREDENTIALS)
+                    return False, None, ErrorManager.get_error_by_code(INVALID_TOKEN)
             except:
                 return False, None, ErrorManager.get_error_by_code(INVALID_TOKEN)
         else:
@@ -251,19 +258,19 @@ class Manager:
                         return False, None, '', ErrorManager.get_error_by_code(INVALID_TOKEN)
                 else:
                     return False, None, '', ErrorManager.get_error_by_code(INVALID_TOKEN)
-                if self.user_model.objects.filter(**{self.social_id_field:id}).exists():
-                    user_instance=self.user_model.objects.get(**{self.social_id_field:id})
+                if self.user_model.objects.filter(**{self.social_id_field:id, self.social_origin_field:origin}).exists():
+                    user_instance=self.user_model.objects.get(**{self.social_id_field:id, self.social_origin_field:origin})
                     if self.active_field_name==None or getattr(user_instance, self.active_field_name):
                         token=self._generate_token(user_instance, 0)
                         if token!=None:
                             return True, user_instance, token, ErrorManager.get_error_by_code(NO_ERROR)
                         else:
-                            return False, None, '', ErrorManager.get_error_by_code(INTERNAL_ERROR)
+                            return False, None, '0', ErrorManager.get_error_by_code(BAD_GENERATED_TOKEN)
                     else:
                         return False, None, '', ErrorManager.get_error_by_code(INVALID_CREDENTIALS)
-                elif self.user_model.objects.filter(**{self.login_id_field_name:email, f'{self.social_id_field}__isnull':True, f'{self.password_field_name}__isnull':True}).exists():
-                    user_instance=self.user_model.objects.get(**{self.login_id_field_name:email, f'{self.social_id_field}__isnull':True, f'{self.password_field_name}__isnull':True})
-                    if self.active_field_name==None or getattr(user_instance, self.active_field_name):
+                elif self.user_model.objects.filter(**{self.login_id_field_name:email}).exists():
+                    user_instance=self.user_model.objects.get(**{self.login_id_field_name:email})
+                    if self.active_field_name==None or not getattr(user_instance, self.active_field_name):
                         setattr(user_instance, self.social_id_field, id)
                         setattr(user_instance, self.social_origin_field, origin)
                         if self.active_field_name!=None:
@@ -273,27 +280,24 @@ class Manager:
                         if token!=None:
                             return True, user_instance, token, ErrorManager.get_error_by_code(NO_ERROR)
                         else:
-                            return False, None, '', ErrorManager.get_error_by_code(INTERNAL_ERROR)
+                            return False, None, '1', ErrorManager.get_error_by_code(BAD_GENERATED_TOKEN)
                     else:
-                        return False, None, '', ErrorManager.get_error_by_code(INVALID_CREDENTIALS)
+                        return False, None, '', ErrorManager.get_error_by_code(SUSPENDED_USER)
                 else:
-                    if not self.user_model.objects.filter(**{self.login_id_field_name:email}).exists():
-                        user_instance=self.user_model(**{self.social_id_field:id, self.name_field_name:nombre, self.login_id_field_name:email, self.social_origin_field:origin})
-                        if self.active_field_name!=None:
-                            setattr(user_instance, self.active_field_name, True)
-                        photo=self.download_photo(urlfoto)
-                        fname=HashManager.getSHA1file(photo)
-                        getattr(user_instance, self.photo_field_name).save(f'{fname}.jpg', photo, save=True)
-                        user_instance.save()
-                        token=self._generate_token(user_instance, 0)
-                        if token!=None:
-                            return True, user_instance, token, ErrorManager.get_error_by_code(NO_ERROR)
-                        else:
-                            return False, None, '', ErrorManager.get_error_by_code(INTERNAL_ERROR)
+                    user_instance=self.user_model(**{self.social_id_field:id, self.name_field_name:nombre, self.login_id_field_name:email, self.social_origin_field:origin})
+                    if self.active_field_name!=None:
+                        setattr(user_instance, self.active_field_name, True)
+                    photo=self.download_photo(urlfoto)
+                    fname=HashManager.getSHA1file(photo)
+                    getattr(user_instance, self.photo_field_name).save(f'{fname}.jpg', photo, save=True)
+                    user_instance.save()
+                    token=self._generate_token(user_instance, 0)
+                    if token!=None:
+                        return True, user_instance, token, ErrorManager.get_error_by_code(NO_ERROR)
                     else:
-                        return False, None, '', ErrorManager.get_error_by_code(USER_ALREADY_EXISTS)
-            except:
-                return False, None, '', ErrorManager.get_error_by_code(INTERNAL_ERROR)
+                        return False, None, '2', ErrorManager.get_error_by_code(BAD_GENERATED_TOKEN)
+            except Exception as e:
+                return False, None, '', ErrorManager.get_error_by_code(error_code=INTERNAL_ERROR, custom_message=str(e), custom_description=str(e))
         else:
             return False, None, '', ErrorManager.get_error_by_code(INTERNAL_ERROR)
 
